@@ -2,7 +2,7 @@ package Crypt::SSLeay;
 
 use strict;
 use vars '$VERSION';
-$VERSION = '0.53_05';
+$VERSION = '0.56_01';
 
 eval {
     require XSLoader;
@@ -58,8 +58,8 @@ Crypt::SSLeay - OpenSSL support for LWP
 
 =head1 DESCRIPTION
 
-This document describes C<Crypt::SSLeay> version 0.53_05, released
-2007-03-26.
+This document describes C<Crypt::SSLeay> version 0.56_01, released
+2007-08-09.
 
 This perl module provides support for the https protocol under LWP,
 to allow an C<LWP::UserAgent> object to perform GET, HEAD and POST
@@ -117,6 +117,16 @@ this module. You can get the latest OpenSSL package from:
 
   http://www.openssl.org/
 
+On Debian systems, you will need to install the libssl-dev package,
+at least for the duration of the build (it may be removed afterwards).
+
+Other package-based systems may require something similar. The key
+is that Crypt::SSLeay makes calls to the OpenSSL library, and how
+to do so is specified in the C header files that come with the
+library.  Some systems break out the header files into a separate
+package from that of the libraries. Once the program has been built,
+you don't need the headers any more.
+
 When installing openssl make sure your config looks like:
 
   ./config --openssldir=/usr/local/openssl
@@ -159,17 +169,34 @@ using the C<make> * commands as shown below.
 
   * use nmake or dmake on Win32
 
+For unattended (batch) installations, to be absolutely certain that
+F<Makefile.PL> does not prompt for questions on STDIN, set the
+following environment variable beforehand:
+
+  PERL_MM_USE_DEFAULT=1
+
+(This is true for any CPAN module that uses C<ExtUtils::MakeMaker>).
+
 =head3 Windows
+
 C<Crypt::SSLeay> builds correctly with Strawberry Perl.
 
-For
-Activestate users, the PPM package is the recommended approach
-for installing. See http://www.activestate.com/ . An
-alternative method is to use Randy Kobes's PPM repository. The
-following command will install the package for ActivePerl:
+For Activestate users, the ActiveState company does not have a
+permit from the Canadian Federal Government to distribute cryptographic
+software. This prevents C<Crypt::SSLeay> from being distributed as
+a PPM package from their repository. See
+L<http://aspn.activestate.com/ASPN/docs/ActivePerl/5.8/faq/ActivePerl-faq2.html#crypto_packages>
+for more information on this issue.
+
+You may download it from Randy Kobes's PPM repository by using
+the following command:
 
   ppm install http://theoryx5.uwinnipeg.ca/ppms/Crypt-SSLeay.ppd
 
+An alternative is to add the uwinnipeg.ca PPM repository to your
+local installation. See L<http://cpan.uwinnipeg.ca/htdocs/faqs/ppm.html>
+for more details.
+
 =head3 VMS
 
 It is assumed that the OpenSSL installation is located at
@@ -341,10 +368,19 @@ module.
 Thanks to Jeff Lavallee for help with alarms on read failures (CPAN
 bug #12444).
 
+Thanks to Guenter Knauf for significant improvements in configuring
+things in Win32 and Netware lands.
+
 =head1 SEE ALSO
 
 =over 4
 
+=item Net::SSL
+
+If you have downloaded this distribution as of a dependency
+of another distribution, it's probably due to this module
+(which is included in this distribution).
+
 =item Net::SSLeay
 
 A module that offers access to the OpenSSL API directly from Perl.
@@ -371,9 +407,8 @@ Please report all bugs at
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Crypt-SSLeay>.
 
 This module was originally written by Gisle Aas, and was subsequently
-maintained by Joshua Chamas.
-
-This module is currently maintained by David Landgren.
+maintained by Joshua Chamas. It is currently maintained by David
+Landgren.
 
 =head1 COPYRIGHT
 
