@@ -6,7 +6,7 @@ use Socket;
 use Carp;
 
 use vars qw(@ISA $VERSION $NEW_ARGS);
-$VERSION = '2.80';
+$VERSION = '2.82';
 
 require IO::Socket;
 @ISA=qw(IO::Socket::INET);
@@ -24,7 +24,7 @@ sub _default_context {
 }
 
 sub _alarm_set {
-    return if $^O eq 'MSWin32';
+    return if $^O eq 'MSWin32' or $^O eq 'Netware';
     alarm(shift);
 }
 
@@ -76,6 +76,11 @@ sub timeout {
     shift->SUPER::timeout || 60;
 }
 
+sub blocking {
+    my $self = shift;
+    $self->SUPER::blocking(@_);
+}
+
 sub connect {
     my $self = shift;
 
@@ -125,7 +130,7 @@ sub connect {
             local $SIG{PIPE} = \&die;
             $rv = eval { $ssl->connect; };
         }
-        if ($rv <= 0) {
+        if (not defined $rv or $rv <= 0) {
             _alarm_set(0);
             $ssl = undef;
             my %args = (%$new_arg, %$arg);
@@ -516,6 +521,16 @@ Is an alias of C<read>.
 Returns the timeout value of the socket as defined by the implementing
 class or 60 seconds by default.
 
+=item blocking
+
+Returns a boolean indicating whether the underlying socket is in
+blocking mode. By default, Net::SSL sockets are in blocking mode.
+
+    $sock->blocking(0); # set to non-blocking mode
+
+This method simply calls the underlying C<blocking> method of the
+IO::Socket object.
+
 =item write
 
 Writes the parameters passed in (thus, a list) to the socket. Returns
